==> isis-fish-4.1.0.2-sources.jar: fr/ifremer/isisfish/simulator/SimulationExportResultWrapper.java <==
/*
 * #%L
 * IsisFish
 * 
 * $Id: SimulationExportResultWrapper.java 3124 2010-11-29 18:14:09Z chatellier $
 * $HeadURL$
 * %%
 * Copyright (C) 2007 - 2010 Ifremer, Code Lutin, Cédric Pineau, Benjamin Poussin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * #L%
 */

package fr.ifremer.isisfish.simulator;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import fr.ifremer.isisfish.IsisFishException;
import fr.ifremer.isisfish.datastore.ExportStorage;
import fr.ifremer.isisfish.datastore.SimulationStorage;
import fr.ifremer.isisfish.export.Export;
import fr.ifremer.isisfish.export.ExportHelper;
import fr.ifremer.isisfish.export.SensitivityExport;

/**
 * Export simulation listener.
 * 
 * Do export after simulation ends.
 *
 * Created: 14 nov. 07 00:22:51
 *
 * @author poussin
 * @version $Revision: 3124 $
 *
 * Last update: $Date: 2010-11-29 19:14:09 +0100 (Mon, 29 Nov 2010) $
 * by : $Author: chatellier $
 */
public class SimulationExportResultWrapper implements SimulationListener {

    /** Class logger. */
    private static Log log = LogFactory
            .getLog(SimulationExportResultWrapper.class);

    /*
     * @see fr.ifremer.isisfish.simulator.SimulationListener#afterSimulation(fr.ifremer.isisfish.simulator.SimulationContext)
     */
    @Override
    public void afterSimulation(SimulationContext context) {
        SimulationStorage simulation = context.getSimulationStorage();
        SimulationParameter parameters = simulation.getParameter();
        File rootDirectory = simulation.getDirectory();

        // Ici on contantene les 2 listes d'exports
        
        // first, make export instances based on export
        // names
        List<Export> allExports = new ArrayList<Export>();
        if (parameters.getExportNames() != null) {
            for (String exportName : parameters.getExportNames()) {
                try {
                    ExportStorage storage = ExportStorage.getExport(exportName);
                    Export export = storage.getNewExportInstance();
                    allExports.add(export);
                } catch (IsisFishException e) {
                    if (log.isErrorEnabled()) {
                        log.error("Can't get export instance " + exportName, e);
                    }
                }
            }
        }
        
        // second, add already instanciated sensitivity
        // exports (with parameters)
        List<SensitivityExport> sensitivityExports = parameters.getSensitivityExport();
        if (sensitivityExports != null) {
            allExports.addAll(sensitivityExports);
        }
        
        // make exports
        if (!allExports.isEmpty()) {
            File exportDir = SimulationStorage
                    .getResultExportDirectory(rootDirectory);
            exportDir.mkdirs();
            ExportHelper.doExport(simulation, exportDir, allExports,
                    rootDirectory);
        }
    }

    /*
     * @see fr.ifremer.isisfish.simulator.SimulationListener#beforeSimulation(fr.ifremer.isisfish.simulator.SimulationContext)
     */
    @Override
    public void beforeSimulation(SimulationContext context) {
    }
}

==> isis-fish-4.1.1.1-sources.jar: fr/ifremer/isisfish/simulator/SimulationExportResultWrapper.java <==
/*
 * #%L
 * IsisFish
 * 
 * $Id: SimulationExportResultWrapper.java 3745 2012-08-30 12:45:25Z echatellier $
 * $HeadURL$
 * %%
 * Copyright (C) 2007 - 2010 Ifremer, Code Lutin, Cédric Pineau, Benjamin Poussin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * #L%
 */

package fr.ifremer.isisfish.simulator;

import static org.nuiton.i18n.I18n._;
import java.io.File;
import java.util.ArrayList;
import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import fr.ifremer.isisfish.IsisFishException;
import fr.ifremer.isisfish.datastore.ExportStorage;
import fr.ifremer.isisfish.datastore.SimulationStorage;
import fr.ifremer.isisfish.export.Export;
import fr.ifremer.isisfish.export.ExportHelper;
import fr.ifremer.isisfish.export.SensitivityExport;

/**
 * Export simulation listener.
 * 
 * Do export after simulation ends.
 *
 * Created: 14 nov. 07 00:22:51
 *
 * @author poussin
 * @version $Revision: 3745 $
 *
 * Last update: $Date: 2012-08-30 14:45:25 +0200 (Thu, 30 Aug 2012) $
 * by : $Author: echatellier $
 */
public class SimulationExportResultWrapper implements SimulationListener {

    /** Class logger. */
    private static Log log = LogFactory
            .getLog(SimulationExportResultWrapper.class);

    /*
     * @see fr.ifremer.isisfish.simulator.SimulationListener#afterSimulation(fr.ifremer.isisfish.simulator.SimulationContext)
     */
    @Override
    public void afterSimulation(SimulationContext context) {
        SimulationStorage simulation = context.getSimulationStorage();
        SimulationParameter parameters = simulation.getParameter();
        File rootDirectory = simulation.getDirectory();
        SimulationControl control = context.getSimulationControl();

        // Ici on contantene les 2 listes d'exports

        // first, make export instances based on export
        // names
        List<Export> allExports = new ArrayList<Export>();
        if (parameters.getExportNames() != null) {
            for (String exportName : parameters.getExportNames()) {
                try {
                    ExportStorage storage = ExportStorage.getExport(exportName);
                    Export export = storage.getNewExportInstance();
                    allExports.add(export);
                } catch (IsisFishException e) {
                    if (log.isErrorEnabled()) {
                        log.error("Can't get export instance " + exportName, e);
                    }
                }
            }
        }
        
        // second, add already instanciated sensitivity
        // exports (with parameters)
        List<SensitivityExport> sensitivityExports = parameters.getSensitivityExport();
        if (sensitivityExports != null) {
            allExports.addAll(sensitivityExports);
        }
        
        // make exports
        if (!allExports.isEmpty()) {
            control.setText(_("isisfish.message.export.export"));
            File exportDir = SimulationStorage
                    .getResultExportDirectory(rootDirectory);
            exportDir.mkdirs();
            ExportHelper.doExport(simulation, exportDir, allExports,
                    rootDirectory);
        }
    }

    /*
     * @see fr.ifremer.isisfish.simulator.SimulationListener#beforeSimulation(fr.ifremer.isisfish.simulator.SimulationContext)
     */
    @Override
    public void beforeSimulation(SimulationContext context) {
    }
}
